from bs4 import BeautifulSoup
from ._helpers import clean_string

def attorneys(oscn_html):
    attorney_list = []
    soup = BeautifulSoup(oscn_html, 'html.parser')
    attorneys_h2 = soup.find('h2', 'section attorneys')
    attorney_table = None

    attorney_table = attorneys_h2.find_next_sibling('table')
    current_h2  = attorney_table.find_previous_sibling('h2')
    if attorneys_h2 == current_h2:
        rows = attorney_table.find('tbody').find_all('tr')
        for row in rows:
            row_tds = row.find_all('td')
            attorney_with_address = (
                [ clean_string(s) for s in row_tds[0].stripped_strings]
            )
            representing = (clean_string(row_tds[1].text))
            attorney_list.append(
                {'name': attorney_with_address[0],
                 'address' : attorney_with_address,
                 'representing': representing
                }
            )
    return attorney_list

# add this attribute to allow it to be added to request objects
setattr(attorneys, 'target', ['Case'])
setattr(attorneys, '_default_value', [])



import re
from bs4 import BeautifulSoup

from ._helpers import find_values, lists2dict

# count_re = r'Count as Filed:[^A-Z]*([A-Z|\d]*),\s(.*)'
# count_details = re.compile(count_re, re.M)



def counts(oscn_html):
    count_list = []
    soup = BeautifulSoup(oscn_html, 'html.parser')
    counts = soup.find_all('div', 'CountsContainer')
    if counts:
        for count in counts:
            count_keys = ['Count as Disposed', 'Count as Filed', 'Disposed', 'Date of Offense']
            count_values = find_values(count, count_keys)
            count_desc = (
                    count_values['Count as Disposed']
                    if count_values['Count as Disposed']
                    else count_values['Count as Filed']
            )

            # find violation
            found_it = False
            violated_statute=''
            for str in count.strings:
                if found_it:
                    violated_statute = str
                    break
                found_it = True if 'violation' in str.lower() else False


            save_count_info = {
                'party' : count.nobr.text,
                'offense': count_values['Date of Offense'],
                'description': count_desc,
                'disposed': count_values['Disposed'],
                'violation': violated_statute
                }
            count_list.append(save_count_info)
    else:
        count_start = soup.find('h2', 'section counts')
        next_sibling = count_start.find_next_sibling('p')
        if next_sibling:
            while next_sibling.name != 'h2':
                if next_sibling.name == 'p':
                    next_sibling.strong.extract()
                    count_list.append(
                        {'description': next_sibling.text.strip()})
                next_sibling = next_sibling.next_sibling

    return count_list

setattr(counts, 'target', ['Case'])
setattr(counts, '_default_value', [])




import os, errno
from io import BytesIO
import gzip
import json

from types import FunctionType

import logging
import warnings

import requests
from requests.exceptions import ConnectionError

import boto3
import botocore
s3 = boto3.resource('s3')
s3_client = boto3.client('s3')

from .. import settings

from ..parse import append_parsers

oscn_url = settings.OSCN_CASE_URL
warnings.filterwarnings("ignore")
logger = logging.getLogger('oscn')

logger.setLevel(logging.INFO)

class Case(object):
    headers = settings.OSCN_REQUEST_HEADER
    response = False

    def __init__(self, index=False, type='CF', county='tulsa', year='2019', number=1, cmid=False, **kwargs):
        if index:
            index_parts = index.split('-')
            if len(index_parts)==4:
                self.county, self.type, self.year, number_str = index_parts
                self.number = int(number_str)
            elif len(index_parts)==2:
                self.county, number_str = index_parts
                self.number = int(number_str)
                self.type = 'IN'
        else:
            self.county = county
            self.year = year
            self.number = int(number)
            self.type = 'IN' if county == 'appellate' else type

        self.cmid = (self.type == 'cmid')
        self.source = kwargs['source'] if 'source' in kwargs else False

        if 'text' in kwargs:
            self.text = kwargs['text']
            return self
        else:
            self.directory = kwargs['directory'] if 'directory' in kwargs else ''
            self.bucket = kwargs['bucket'] if 'bucket' in kwargs else ''
            if self.directory:
                self._open_file()
            elif self.bucket:
                self._open_s3_object()
            else:
                self._request()

    @property
    def oscn_number(self):
        if self.county == 'appellate':
            return f'{self.number}'
        else:
            return f'{self.type}-{self.year}-{self.number}'

    @property
    def index(self):
        return f'{self.county}-{self.oscn_number}'

    @property
    def path(self):
        if self.county == 'appellate':
            return f'{self.directory}/{self.county}'
        else:
            return f'{self.directory}/{self.county}/{self.type}/{self.year}'

    @property
    def file_name(self):
        return f'{self.path}/{self.number}.case'

    @property
    def s3_key(self):
        if self.county == 'appellate':
            return f'{self.county}/{self.number}.case'
        else:
            return f'{self.county}/{self.type}/{self.year}/{self.number}.case'


    def save(self, **kwargs):
        case_data = {
            'source': self.source,
            'index' : self.index,
            'text': self.text,
        }
        file_data = gzip.compress(bytes(json.dumps(case_data),'utf-8'))

        self.directory = kwargs['directory'] if 'directory' in kwargs else ''
        self.bucket = kwargs['bucket'] if 'bucket' in kwargs else ''
        if self.directory:
            if not os.path.exists(os.path.dirname(self.file_name)):
                try:
                    os.makedirs(os.path.dirname(self.file_name))
                except OSError as exc: # Guard against race condition
                    if exc.errno != errno.EEXIST:
                        raise
            with open(self.file_name, 'wb') as open_file:
                open_file.write(file_data)

        if self.bucket:
            try:
                s3.meta.client.head_bucket(Bucket=self.bucket)
            except botocore.exceptions.ClientError as e:
                error_code = e.response['Error']['Code']
                if error_code == '404' or error_code == '403':
                    s3.create_bucket(Bucket=self.bucket)
                else:
                    raise e
            s3.Bucket(self.bucket).put_object(Key=self.s3_key, Body=file_data)

    def _open_file(self):
        try:
            with gzip.GzipFile(self.file_name, 'r') as open_file:
                saved_data = json.loads(open_file.read().decode('utf-8'))
                self.__init__(**saved_data)
            self.valid = True
        except FileNotFoundError:
            self.valid = False

    def _open_s3_object(self):
        try:
            s3_object = s3_client.get_object(Bucket=self.bucket, Key=self.s3_key)
            bytes = BytesIO(s3_object['Body'].read())
            unzipped_stream = (
                gzip.GzipFile(None, 'rb', fileobj=bytes).read().decode('utf-8'))
            saved_data = json.loads(unzipped_stream)
            self.__init__(**saved_data)
            self.valid = True
        except botocore.exceptions.ClientError as e:
                error_code = e.response['Error']['Code']
                if error_code == 'NoSuchKey':
                    self.valid = False
                else:
                    raise e

    def _valid_response(self, response):
        if not response.ok:
            return False
        for msg in settings.INVALID_CASE_MESSAGES:
            if msg in response.text:
                logger.info("Case %s is invalid", self.oscn_number)
                return False
        return True

    def _request(self, attempts_left=settings.MAX_EMPTY_CASES):
        params = {'db': self.county}
        if self.cmid:
            params['cmid'] = self.number
        else:
            params['number'] = self.oscn_number

        try:
            response = (
                requests.post(
                    oscn_url, params,
                    headers=self.headers,
                    verify=False
                )
            )
        except ConnectionError:
            if attempts_left > 0:
                return self._request(attempts_left=attempts_left-1)
            else:
                raise ConnectionError
        if self._valid_response(response):
            self.valid = True
            self.source = f'{response.url}?{response.request.body}'
            self.text = response.text
            for msg in settings.UNUSED_CASE_MESSAGES:
                if msg in response.text:
                    self.valid = False
                    return
        else:
            self.valid = False


# This next line adds properties to the OSCNrequest as a shortcut
# for parsing.  This allows access to parse results such as:
# name = Case.judge
# or
# counts = Case.counts
append_parsers(Case)


class CaseList(object):

    def __init__(self,
                 types=[],
                 counties=[],
                 years=[],
                 start=1, stop=20000, **kwargs):

        self.start = start
        self.stop = stop
        self.filters = []

        # allow kwargs to override certain args
        self.types = kwargs['type'] if 'type' in kwargs else types
        self.counties = kwargs['county'] if 'county' in kwargs else counties
        self.years = kwargs['year'] if 'year' in kwargs else years

        # Allow passing a string to list keywords
        # make a str into a single element list otherwise return the value
        str_to_list = lambda val: [val] if type(val) is str else val
        self.types = str_to_list(self.types)
        self.counties = str_to_list(self.counties)
        self.years = str_to_list(self.years)

        # create case request based on storage option
        if 'directory' in kwargs:
            self._request_case = self._make_case_requester(directory=kwargs['directory'])
        elif 'bucket' in kwargs:
            self._request_case = self._make_case_requester(bucket=kwargs['bucket'])
        else:
            self._request_case = self._make_case_requester()

        self.all_cases = self._case_generator()

    def _make_case_requester(self, **kwargs):
        def case_request(index=False):
            kwargs['index']=index
            return Case(**kwargs)
        return case_request

    def _request_generator(self, start, stop):
        case_numbers = range(start, stop+1)
        for county in self.counties:
            for case_type in self.types:
                for year in self.years:
                    self.exit_year = False
                    for num in case_numbers:
                        case_index = f'{county}-{case_type}-{year}-{num}'
                        yield self._request_case(case_index)
                        if self.exit_year:
                            break
        # raise StopIteration

    def _case_generator(self):
        request_attempts=10
        for case in self._request_generator(self.start, self.stop):
            if case.valid:
                request_attempts=10
                if self._passes_filters(case):
                    yield case
                if case.cmids:
                    for cmid in case.cmids:
                        cmid_index = f'{case.county}-cmid-{case.year}-{cmid}'
                        cmid_case = self._request_case(cmid_index)
                        if cmid_case.valid:
                            if self._passes_filters(cmid_case):
                                yield cmid_case
            else:
                if request_attempts > 0:
                    request_attempts -= 1
                else:
                    self.exit_year = True
        # raise StopIteration


    def __iter__(self):
        return self

    def __next__(self):
        return next(self.all_cases)

    def _passes_filters(self, case):
        # iter of all the tests
        run_test = lambda test:test(case)
        test_results = map(run_test, self.filters)
        # see if they are all true
        return all(test_results)

    def find(self, **kwargs):
        for kw in kwargs:
            kw_value = kwargs[kw]
            if isinstance(kw_value, str):
                case_test = lambda case:kw_value in getattr(case, kw)
            elif isinstance(kw_value, FunctionType):
                case_test = lambda case:kw_value(getattr(case, kw))
            self.filters.append(case_test)
        return self



import re

from .. import settings

find_judge = re.compile(r'Judge:\s*([\w\s\,]*)', re.M)
find_titles = re.compile('|'.join(settings.REMOVE_TITLES))
find_name_parts = re.compile(r'(\w+\.*)', re.I)

def judge(oscn_html):
    judge_search = find_judge.search(oscn_html)
    if judge_search.group:
        found_name = judge_search.group(1).upper()
        found_name = find_titles.sub('', found_name)
        if re.search(',', found_name):
            return found_name
        else:
            name_parts = find_name_parts.findall(found_name)
            last_name = name_parts.pop()
            if name_parts == []:
                return last_name
            found_name = last_name + ', ' + ' '.join(name_parts)
            return found_name
    else:
        return None

setattr(judge, 'target', ['Case'])
setattr(judge, '_default_value', [])



from bs4 import BeautifulSoup

from ._helpers import clean_string

def style(oscn_html):
    soup = BeautifulSoup(oscn_html, 'html.parser')
    style_table = soup.find('table', 'caseStyle')
    style_cell = style_table.find('td')
    return clean_string(style_cell.text)

setattr(style, 'target', ['Case'])
setattr(style, '_default_value', "")



import requests
import functools

from bs4 import BeautifulSoup

from . import settings

@functools.lru_cache()
def courts():
    try:
        response = requests.get('https://www.oscn.net/dockets/',
                                headers=settings.OSCN_REQUEST_HEADER,
                                verify=False)
        soup = BeautifulSoup(response.text, 'html.parser')
        form = soup.find('form', action='Results.aspx')
        select = form.find('select', id='db')
        options = select.find_all('option')
        court_vals = [option['value'] for option in options]
        court_vals.remove('all')
        return court_vals
    except:
        return settings.ALL_COURTS





OSCN_CASE_URL = "https://www.oscn.net/dockets/GetCaseInformation.aspx"
OSCN_SEARCH_URL = "https://www.oscn.net/dockets/Results.aspx"

OSCN_REQUEST_HEADER = {
        'User-Agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_13_5) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/67.0.3396.87 Safari/537.36',
        'Accept-Encoding': 'gzip, deflate, br',
        'Accept-Language': 'en-US,en;q=0.9'
        }

REMOVE_TITLES = ['HONORABLE']

INVALID_CASE_MESSAGES = [
    "Case Number is Invalid",
    ]
UNUSED_CASE_MESSAGES = [
    "SKIPPED IN ERROR",
    "Something went wrong",
    'THIS CASE NUMBER WAS NOT USED',
    "is formatted incorrectly or is not found within",
    ">No Record.</td>"
    ]

# How many empty cases in a row to decide we're at the end of the case list?
MAX_EMPTY_CASES = 10


ALL_COURTS = [
    'adair',
    'alfalfa',
    'appellate',
    'atoka',
    'beaver',
    'beckham',
    'blaine',
    'bryan',
    'caddo',
    'canadian',
    'carter',
    'cherokee',
    'choctaw',
    'cimarron',
    'cleveland',
    'coal',
    'comanche',
    'cotton',
    'craig',
    'creek',
    'bristow',
    'drumright',
    'custer',
    'delaware',
    'dewey',
    'ellis',
    'garfield',
    'garvin',
    'grady',
    'grant',
    'greer',
    'harmon',
    'harper',
    'haskell',
    'hughes',
    'jackson',
    'jefferson',
    'johnston',
    'kay',
    'poncacity',
    'kingfisher',
    'kiowa',
    'latimer',
    'leflore',
    'lincoln',
    'logan',
    'love',
    'major',
    'marshall',
    'mayes',
    'mcclain',
    'mccurtain',
    'mcintosh',
    'murray',
    'muskogee',
    'noble',
    'nowata',
    'okfuskee',
    'oklahoma',
    'okmulgee',
    'henryetta',
    'osage',
    'ottawa',
    'payne',
    'pawnee',
    'pittsburg',
    'pontotoc',
    'pottawatomie',
    'pushmataha',
    'rogermills',
    'rogers',
    'seminole',
    'sequoyah',
    'stephens',
    'texas',
    'tillman',
    'tulsa',
    'wagoner',
    'washington',
    'washita',
    'woods',
    'woodward']



from bs4 import BeautifulSoup
from ._helpers import text_values, lists2dict


def docket(oscn_html):
    soup = BeautifulSoup(oscn_html, 'html.parser')
    docket_table = soup.find('table', 'docketlist')
    thead = docket_table.find('thead').find_all('th')
    rows = docket_table.find('tbody').find_all('tr')
    minutes = []

    # make a lower case list of column headers
    columns = [hdr for hdr in map(lambda str:str.lower(), text_values(thead))]

    for row in rows:
        cells = row.find_all('td')
        values = text_values(cells)
        minute = lists2dict(columns, values)
        minute['html'] = row.decode()
        minutes.append(minute)

    # clean up blank dates
    saved_date = minutes[0]['date']
    for idx, min in enumerate(minutes):
        if min['date']:
            saved_date = min['date']
        else:
            min['date'] = saved_date

    return minutes

setattr(docket, 'target', ['Case'])
setattr(docket, '_default_value', [])




import requests
import warnings

from requests.exceptions import ConnectionError

from .. import settings
from .parse import cases

oscn_url = settings.OSCN_SEARCH_URL

# http://www.oscn.net/dockets/Results.aspx
# ?db=all&number=2018-1&lname=&fname=&mname=&DoBMin=&DoBMax=&partytype=&apct=&dcct=&FiledDateL=&FiledDateH=&ClosedDateL=&ClosedDateH=&iLC=&iLCType=&iYear=&iNumber=&citation=


def _request(**kwargs):
    params = {  'db': self.county,
                'lname': self.last,
                'fname':self.first,
                'mname': self.middle
            }
    try:
        response = (
            requests.post(
                oscn_url, params, headers=self.headers, verify=False
            )
        )
    except ConnectionError:
        return self._request(attempts_left=attempts_left-1)

    if response.ok:
        self.text = response.text



def index(index):


class party(object):
    headers = settings.OSCN_REQUEST_HEADER
    response = False

    def __init__(self, county='all', first='', last='', middle='', **kwargs):
        self.county = county
        self.first = first
        self.last = last
        self.middle = middle
            self._request()


# db=all&number=&lname=Bertch&fname=&mname=&DoBMin=&DoBMax=&partytype=&apct=&dcct=&FiledDateL=&FiledDateH=&ClosedDateL=&ClosedDateH=&iLC=&iLCType=&iYear=&iNumber=&citation=



# Some case URL's return a list of 'sbu' caseStyle
# See an example in examples/multi_case_table.html
# this function looks return a list of cmids for if found

from bs4 import BeautifulSoup
from urllib.parse import parse_qs


def cmids(oscn_html):
    soup = BeautifulSoup(oscn_html, 'html.parser')
    cmids = []
    ref_table = soup.find('table', 'multipleRecords')
    if ref_table:
        for row in ref_table.find('tbody').find_all('tr'):
            href = row.find('a')['href']
            cmids += parse_qs(href)['cmid']

    return cmids

setattr(cmids, 'target', ['Case'])
setattr(cmids, '_default_value', [])



from bs4 import BeautifulSoup
from ._helpers import text_values, column_titles, lists2dict, clean_string


def events(oscn_html):
    events = []
    soup = BeautifulSoup(oscn_html, 'html.parser')
    events_start = soup.find('h2', 'section events')
    events_table = events_start.find_next_sibling()
    if events_table.name == 'table':
        thead = events_table.find('thead').find_all('th')
        event_keys = column_titles(thead)
        rows = events_table.find('tbody').find_all('tr')
        for row in rows:
            cells = row.find_all('td')
            values = text_values(cells)
            event = lists2dict(event_keys, values)
            event_font = cells[0].font.extract()
            event_date = clean_string(event_font.text)
            event['date'] = event_date
            event['description'] = clean_string(cells[0].text)
            events.append(event)
    return events

setattr(events, 'target', ['Case'])
setattr(events, '_default_value', [])



import re

from bs4 import BeautifulSoup

from ._helpers import find_values, clean_string


issue_keys = ['Filed Date', 'Filed By', 'Issue']
party_keys = ['Defendant','Plaintiff','Respondent', 'Disposed']

def make_party_dict(**kwargs):
    # test for all keys are empty
    if all(''==v for v in kwargs.values()):
        return False

    party_type = ''
    party_name = ''

    if kwargs['Defendant']:
        party_type = 'defendant'
        party_name = kwargs['Defendant']
    elif kwargs['Plaintiff']:
        party_type = 'plaintiff'
        party_name = kwargs['Plaintiff']
    elif kwargs['Respondent']:
        party_type = 'respondent'
        party_name = kwargs['Respondent']

    return {'type':party_type, 'name': party_name, 'disposed': kwargs['Disposed']}


def issues(oscn_html):
    issue_list = []
    soup = BeautifulSoup(oscn_html, 'html.parser')
    start = soup.find('h2', 'section issues')
    issue_table = start.find_next_sibling('table')

    while re.search('Issue #', issue_table.text):
        # find the issue details
        issue_dict = find_values(issue_table, issue_keys)

        # the next table should be dispositions
        disp_table = issue_table.find_next_sibling('table')

        issue_dict['parties'] = []
        parties_rows = disp_table.find_all('tr')
        for row in parties_rows:
            # remove formatting elements from td
            for td in row.find_all('td'):
                td.string = (' '.join(td.strings))
            party_values = find_values(row, party_keys)
            party_dict = make_party_dict(**party_values)
            if party_dict:
                issue_dict['parties'].append(party_dict)

        issue_list.append(issue_dict)

        # get the next table
        issue_table = disp_table.find_next_sibling('table')

    return issue_list


# add this attribute to allow it to be added to request objects
setattr(issues, 'target', ['Case'])
setattr(issues, '_default_value', [])



from os import listdir
from os.path import splitext
from importlib import import_module
from types import FunctionType



# The following code searches for parse functions to allow them to be
# added to objects as properties using the append_parsers function
# it also imports them so they are available from `oscn.parse`

parse_functions = []

try:
    for py_file in listdir(__path__[0]):
        parse_module = (
            import_module(f'.{splitext(py_file)[0]}', package=__package__)
            )
        for name in dir(parse_module):
            attr = getattr(parse_module, name)
            if isinstance(attr, FunctionType):
                if hasattr(attr, 'target'):
                    # replaces 'from .counts import counts'
                    locals()[name] = attr
                    parse_functions.append(attr)
except NameError:
    pass


def make_safe_parser(fn):
    on_error = fn._default_value if hasattr(fn, '_default_value') else False

    def safe_parser(self):
        try:
            return fn(self.text)
        except:
            return on_error
    return safe_parser


def make_property(parse_function):
    return property(make_safe_parser(parse_function))


# this function accepts a class and searches for
# parsers to be added to
def append_parsers(obj):
    for fn in parse_functions:
        if obj.__name__ in fn.target:
            setattr(obj, fn.__name__, make_property(fn))



from bs4 import BeautifulSoup

from ._helpers import clean_string


def parties(oscn_html):
    names = []
    soup = BeautifulSoup(oscn_html, 'html.parser')
    start = soup.find('h2', 'section party')
    party_p = start.find_next_sibling('p')
    party_links = party_p.find_all('a')
    if party_links:
        names = [link.text for link in party_links]
        # party_p.strings look like "name,type,name,type"
        # [1::2] starts at the 2nd position and gets every other string
        types = [t[1::] for t in [s for s in party_p.strings][1::2]]
    else:
        names = []
        types = []

        def get_name_and_type(string):
            # separates a line like this into name and type
            # HEFFLIN,\xa0 ASHLEY\xa0 LAUREN,\r\nRespondent'
            more_strings = string.split(',')
            # take the last item off the list
            get_type = more_strings.pop(-1)
            # put it back together
            name = ','.join(more_strings)
            return name, get_type

        for party_text in party_p.strings:
            name, party_type = get_name_and_type(party_text)
            names.append(name)
            types.append(party_type)

    def Party(name, type_string):
        return {'name': clean_string(name), 'type': clean_string(type_string)}

    raw_parties = map(Party, names, types)

    return [party for party in raw_parties if party['name']]

# add this attribute to allow it to be added to request objects
setattr(parties, 'target', ['Case'])
setattr(parties, '_default_value', [])



import re
from unicodedata import normalize


def clean_string(some_string):
    # removes escape chars and excess spaces
    normal_str = normalize('NFKD', some_string)
    # remove line breaks
    no_lines = re.sub('\\r\\n|\\n\\n', ' ', normal_str)
    # reduce spaces
    condensed = re.sub(' +', ' ', no_lines)
    return condensed.strip()


def text_values(ResultSet):
    return [clean_string(el.text) for el in ResultSet]


def column_titles(thead):
    return [hdr for hdr in map(lambda str:str.lower(), text_values(thead))]


def add_properties(obj, names, values):
    for idx, value in enumerate(values):
        setattr(obj, names[idx], value)


def lists2dict(keys, values):
    return {k: v for k, v in map(lambda k, v: (k, v), keys, values)}


def find_values(soup, key_names):
    key_values = []
    for key in key_names:
        key_found = soup.find(string=re.compile(f'{key}:'))
        key_value = key_found.split(':')[1] if key_found else ''
        key_values.append(clean_string(key_value))
    return lists2dict(key_names, key_values)



import re
from datetime import datetime


def make_pattern_finder(pattern):
    find = re.compile(pattern, re.M)

    def find_pattern(oscn_html):
        search = find.search(oscn_html)
        try:
            return search.group(1)
        except AttributeError:
            return '01/01/1970'

    return find_pattern

find_filed = make_pattern_finder(r'Filed:\s*([\/\d]*)')
find_filed.__name__ = 'filed'
setattr(find_filed, 'target', ['Case'])

find_closed = make_pattern_finder(r'Closed:\s*([\/\d]*)')
find_closed.__name__ = 'closed'
setattr(find_closed, 'target', ['Case'])

find_offense = make_pattern_finder(r'Date.of.Offense:\s*([\/\d]*)')
find_offense.__name__ = 'offense'
setattr(find_offense, 'target', ['Case'])



from setuptools import setup, find_packages


with open("README.md", "r") as fh:
    long_description = fh.read()


setup(  name='oscn',
        version='0.0.0.59',
        description='Oklahoma State Courts Network case parsing utilities',
        long_description=long_description,
        long_description_content_type="text/markdown",
        url='https://github.com/codefortulsa/oscn',
        author='Code for Tulsa',
        author_email='code-for-tulsa@googlegroups.com',
        license='MIT',
        packages=find_packages(),
        zip_safe=False,
        install_requires=[
            'requests',
            'beautifulsoup4',
            'boto3'
            ],
        classifiers=[
            'Programming Language :: Python',
            'Programming Language :: Python :: 3.6',
            ],
        )
